import { Component, EventEmitter, HostListener, Input, Output } from '@angular/core';
import { animate, state, style, transition, trigger } from '@angular/animations';
var DialogComponent = /** @class */ (function () {
    function DialogComponent() {
        this.onClick = new EventEmitter();
        this.modalFadeIn = false;
        this.modalState = 'inactive';
    }
    DialogComponent.prototype.ngOnInit = function () {
        var _this = this;
        //need to fade in the modal
        this.modalFadeIn = true;
        setTimeout(function () { return _this.modalState = 'active'; });
    };
    DialogComponent.prototype.closeModal = function () {
        this.btnClick(0);
    };
    DialogComponent.prototype.btnClick = function (val) {
        var _this = this;
        this.modalState = 'inactive';
        // 300ms this much time the animation takes to close the modal
        setTimeout(function () {
            _this.onClick.emit(val);
            _this.modalFadeIn = false;
        }, 300);
    };
    DialogComponent.prototype.onActionKeyPress = function (event) {
        var currentDefaultIndex = this.dialog.actionButtons.findIndex(function (i) { return i.default; });
        this.dialog.actionButtons[currentDefaultIndex].default = false;
        var len = this.dialog.actionButtons.length;
        if (event.keyCode == 37) {
            var newDefaultIndex = ((currentDefaultIndex - 1) + len) % len;
            this.dialog.actionButtons[newDefaultIndex].default = true;
        }
        else if (event.keyCode == 39) {
            var newDefaultIndex = ((currentDefaultIndex - 1) + len) % len;
            this.dialog.actionButtons[newDefaultIndex].default = true;
        }
        else if (event.keyCode == 13) {
            this.btnClick(this.dialog.actionButtons[currentDefaultIndex].value);
        }
        else if (event.keyCode == 27) {
            this.btnClick(0);
        }
    };
    DialogComponent.decorators = [
        { type: Component, args: [{
                    animations: [
                        trigger('modalState', [
                            state('inactive', style({
                                opacity: '0',
                                transform: 'translateY(-50%)'
                            })),
                            state('active', style({
                                opacity: '1',
                                transform: 'translateY(0)'
                            })),
                            transition('inactive <=>active', animate('500ms ease-in'))
                        ]),
                        trigger('modalOverlay', [
                            state('inactive', style({
                                background: 'transparent'
                            })),
                            state('active', style({
                                background: 'rgba(0,0,0,0.4)'
                            })),
                            transition('inactive <=>active', animate('500ms ease-in'))
                        ]),
                    ],
                    selector: 'alm-dialog',
                    styles: [require('./dialog.component.css').toString()],
                    template: require('./dialog.component.html')
                },] },
    ];
    /** @nocollapse */
    DialogComponent.ctorParameters = function () { return []; };
    DialogComponent.propDecorators = {
        'dialog': [{ type: Input },],
        'onClick': [{ type: Output, args: ['pfDialogClick',] },],
        'onActionKeyPress': [{ type: HostListener, args: ['window:keydown', ['$event'],] },],
    };
    return DialogComponent;
}());
export { DialogComponent };
//# sourceMappingURL=dialog.component.js.map