import { Directive, EventEmitter, ElementRef, Input, Output, HostListener } from '@angular/core';
var AlmEditableDirective = /** @class */ (function () {
    function AlmEditableDirective(elementRef) {
        this.elementRef = elementRef;
        this.onUpdate = new EventEmitter();
        this.editable = true;
        this.content = '';
        this.element = this.elementRef.nativeElement;
    }
    AlmEditableDirective.prototype.ngOnInit = function () {
        this.element.style.whiteSpace = 'pre-wrap';
        if (this.editable) {
            this.makeEditable();
        }
    };
    AlmEditableDirective.prototype.ngOnChanges = function () {
        if (this.editable) {
            this.makeEditable();
        }
        else {
            this.makeNonEditable();
        }
    };
    AlmEditableDirective.prototype.onEdit = function () {
        var newContent = this.element.innerText;
        if (this.content !== newContent) {
            this.content = newContent;
            this.onUpdate.emit(this.content);
        }
    };
    AlmEditableDirective.prototype.makeEditable = function () {
        this.element.setAttribute('contenteditable', 'true');
        this.element.focus();
    };
    AlmEditableDirective.prototype.makeNonEditable = function () {
        this.element.removeAttribute('contenteditable');
    };
    AlmEditableDirective.prototype.listenToKeypress = function (event) {
        if (this.editable) {
            this.onEdit();
        }
    };
    AlmEditableDirective.prototype.focusField = function () {
        var _this = this;
        setTimeout(function () {
            if (_this.element.childNodes.length) {
                var range = document.createRange();
                var sel = window.getSelection();
                range.setStart(_this.element.childNodes[_this.element.childNodes.length - 1], _this.element.childNodes[_this.element.childNodes.length - 1].childNodes.length);
                range.collapse(true);
                sel.removeAllRanges();
                sel.addRange(range);
            }
        });
    };
    AlmEditableDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[almEditable]',
                    exportAs: 'almEditable'
                },] },
    ];
    /** @nocollapse */
    AlmEditableDirective.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    AlmEditableDirective.propDecorators = {
        'onUpdate': [{ type: Output, args: ['onUpdate',] },],
        'editable': [{ type: Input },],
        'listenToKeypress': [{ type: HostListener, args: ['window:keyup', ['$event'],] },],
        'focusField': [{ type: HostListener, args: ['focus',] },],
    };
    return AlmEditableDirective;
}());
export { AlmEditableDirective };
//# sourceMappingURL=almeditable.directive.js.map