import { Observable } from 'rxjs';
import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
/**
 * This provides a very simple retrieval of issue information from
 * GitHub. It uses the non-authorized public API of GitHub, so it
 * is rate-limited (to 60 requests/hr currently). To avoid as much
 * requests as possible, the request responses are cached here.
 */
var GitHubLinkService = /** @class */ (function () {
    function GitHubLinkService(http) {
        this.http = http;
        this.linkCache = [];
    }
    /*
     * This retrieves GitHub JSON information for a given remote GH issue. The given
     * linkData needs to contain 'org', 'repo' and 'issue' that refers to a GitHub issue.
     * The returned data is cached with infinite holding time, effectively only querying
     * once for every GitHub issue for the entire runtime of the service. This is needed
     * because GitHub is enforcing a strict rate limiting.
     */
    GitHubLinkService.prototype.getIssue = function (linkData) {
        var _this = this;
        var cachedData = this.findInCache(linkData);
        if (cachedData) {
            return Observable.of(cachedData);
        }
        else {
            var query = this.http.get('https://api.github.com/repos/' +
                linkData.org + '/' +
                linkData.repo +
                '/issues/' + linkData.issue)
                .catch(function (error) {
                return Observable.of({ state: 'error' });
            });
            query.subscribe(function (data) {
                _this.linkCache.push(data);
            });
            return query;
        }
    };
    GitHubLinkService.prototype.findInCache = function (linkData) {
        for (var i = 0; i < this.linkCache.length; i++) {
            var link = this.linkCache[i];
            if (link.url === 'https://api.github.com/repos/' +
                linkData.org + '/' +
                linkData.repo + '/issues/' +
                linkData.issue) {
                linkData.state = link.state;
                return linkData;
            }
        }
        return null;
    };
    GitHubLinkService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    GitHubLinkService.ctorParameters = function () { return [
        { type: HttpClient, },
    ]; };
    return GitHubLinkService;
}());
export { GitHubLinkService };
//# sourceMappingURL=github-link.service.js.map