import { Directive, EventEmitter, ElementRef, Input, Output, HostListener } from '@angular/core';
var InfiniteScrollDirective = /** @class */ (function () {
    function InfiniteScrollDirective(elementRef) {
        this.elementRef = elementRef;
        this.initItems = new EventEmitter();
        this.fetchMore = new EventEmitter();
        this.eachElementHeightInPx = 20;
        this.fetchThreshold = 5;
        this.pageSize = 10;
        this.lastCheckedHeight = 0;
        this.previousScrollHeight = 0;
        this.element = this.elementRef.nativeElement;
    }
    InfiniteScrollDirective.prototype.ngOnInit = function () {
        this.pageSize = Math.ceil(this.element.offsetHeight / this.eachElementHeightInPx);
        // Page should always have more elements than it can hold
        // Normally twice than threshold value
        this.pageSize += this.fetchThreshold * 2;
        this.initContentItems();
    };
    InfiniteScrollDirective.prototype.initContentItems = function () {
        this.initItems.emit({
            pageSize: this.pageSize
        });
    };
    InfiniteScrollDirective.prototype.onScrollContainer = function (event) {
        if (this.element.scrollHeight > this.lastCheckedHeight) {
            this.previousScrollHeight = this.element.scrollHeight;
            var remainingHeight = this.element.scrollHeight - (this.element.offsetHeight + this.element.scrollTop);
            var remainingElement = Math.ceil(remainingHeight / this.eachElementHeightInPx);
            if (remainingElement < this.fetchThreshold) {
                this.lastCheckedHeight = this.element.scrollHeight;
                this.fetchMore.emit();
            }
        }
        else if (this.element.scrollHeight < this.previousScrollHeight) {
            this.previousScrollHeight = this.element.scrollHeight;
            this.lastCheckedHeight = 0;
            this.element.scrollTop = 0; // Scroll the list to top
        }
    };
    InfiniteScrollDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[almInfiniteScroll]',
                    exportAs: 'almInfiniteScroll'
                },] },
    ];
    /** @nocollapse */
    InfiniteScrollDirective.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    InfiniteScrollDirective.propDecorators = {
        'initItems': [{ type: Output, args: ['initItems',] },],
        'fetchMore': [{ type: Output, args: ['fetchMore',] },],
        'eachElementHeightInPx': [{ type: Input },],
        'fetchThreshold': [{ type: Input },],
        'onScrollContainer': [{ type: HostListener, args: ['scroll', ['$event'],] },],
    };
    return InfiniteScrollDirective;
}());
export { InfiniteScrollDirective };
//# sourceMappingURL=infinitescroll.directive.js.map